InternalFieldType

Enum InternalFieldType 

pub enum InternalFieldType {
Show 20 variants UnresolvedMessage(String), UnresolvedEnum(String), Double, Float, Int64, UInt64, Int32, Fixed64, Fixed32, Bool, String, Group, Message(MessageId), Bytes, UInt32, Enum(EnumId), SFixed32, SFixed64, SInt32, SInt64,
}
The internally tracked type of a field.

The type owns all of its data, and can refer to an internally tracked ID for resolved type references. It’s by design not possible to construct those IDs from outside this module.

Variants



UnresolvedMessage(String)

A message that is yet to be resolved.



UnresolvedEnum(String)

An enum that is yet to be resolved.



Double

The double type.



Float

The float type.



Int64

The int64 type.



UInt64

The uint64 type.



Int32

The int32 type.



Fixed64

The fixed64 type.



Fixed32

The fixed32 type.



Bool

The bool type.



String

The string type.



Group

The group type.



Message(MessageId)

A resolved message type.



Bytes

The bytes type.



UInt32

The uint32 type.



Enum(EnumId)

A resolved enum type.



SFixed32

The sfixed32 type.



SFixed64

The sfixed64 type.



SInt32

The sint32 type.



SInt64

The sint64 type.

Implementations

Source

impl InternalFieldType

pub fn from_proto( proto: FieldDescriptorProto_Type, type_name: &str, ) -> InternalFieldType

Converts a proto field type into a native field type.