MessageDescriptor

Struct MessageDescriptor 

pub struct MessageDescriptor { /* private fields */ }
A descriptor for a single protocol buffer message type.

Implementations

Source

impl MessageDescriptor

pub fn new<S>(name: S) -> MessageDescriptor
where S: Into<String>,

Creates a new message descriptor with the specified message name.

pub fn from_proto(path: &str, proto: &DescriptorProto) -> MessageDescriptor

Reads a message descriptor from a parsed Protobuf descriptor.

pub fn fields(&self) -> &[FieldDescriptor]

All of the fields in the descriptor.

pub fn name(&self) -> &str

The name of the message.

pub fn field_by_name(&self, name: &str) -> Option<&FieldDescriptor>

Finds a field by field name.

pub fn field_by_number(&self, number: i32) -> Option<&FieldDescriptor>

Finds a field by field number.

pub fn add_field(&mut self, descriptor: FieldDescriptor)

Adds a new field to the descriptor.